==> qtjambi-remoteobjects-debuginfo-macos-6.6.1.jar: sources/QtJambiRemoteObjects/QRemoteObjectAbstractPersistedStore_shell.h <==
#ifndef QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H
#define QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectAbstractPersistedStore_shell : public QRemoteObjectAbstractPersistedStore, public QtJambiShellInterface
{
public:
    QRemoteObjectAbstractPersistedStore_shell(QObject* parent0 = nullptr);
    ~QRemoteObjectAbstractPersistedStore_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVariant> restoreProperties(const QString& repName0, const QByteArray& repSig1) override;
    void saveProperties(const QString& repName0, const QByteArray& repSig1, const QList<QVariant>& values2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectAbstractPersistedStore_access : public QRemoteObjectAbstractPersistedStore
{
    jobject __qt_restoreProperties_cref_QString_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1);
    void __qt_saveProperties_cref_QString_cref_QByteArray_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject values2);
};

#endif // QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H

==> qtjambi-remoteobjects-debuginfo-macos-6.7.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectAbstractPersistedStore_shell.h <==
#ifndef QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H
#define QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectAbstractPersistedStore_shell : public QRemoteObjectAbstractPersistedStore, public QtJambiShellInterface
{
public:
    QRemoteObjectAbstractPersistedStore_shell(QObject* parent0 = nullptr);
    ~QRemoteObjectAbstractPersistedStore_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QRemoteObjectAbstractPersistedStore_mshell;
    friend class QRemoteObjectAbstractPersistedStore_oshell;
};


class QRemoteObjectAbstractPersistedStore_mshell : public QRemoteObjectAbstractPersistedStore_shell
{
public:
    using QRemoteObjectAbstractPersistedStore_shell::QRemoteObjectAbstractPersistedStore_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QRemoteObjectAbstractPersistedStore_oshell : public QRemoteObjectAbstractPersistedStore_mshell
{
public:
    using QRemoteObjectAbstractPersistedStore_mshell::QRemoteObjectAbstractPersistedStore_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVariant> restoreProperties(const QString& repName0, const QByteArray& repSig1) override;
    void saveProperties(const QString& repName0, const QByteArray& repSig1, const QList<QVariant>& values2) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectAbstractPersistedStore_access : public QRemoteObjectAbstractPersistedStore
{
    jobject __qt_restoreProperties_cref_QString_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1);
    void __qt_saveProperties_cref_QString_cref_QByteArray_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring repName0, QtJambiNativeID repSig1, jobject values2);
};

#endif // QREMOTEOBJECTABSTRACTPERSISTEDSTORE_SHELL_H
